@@ -3,17 +3,17 @@ Finance-specific data cleaning functions.
 """
 
 import json
-from datetime import date, datetime
+from datetime import date
 from functools import lru_cache
-from typing import Optional
 
 import pandas as pd
 import pandas_flavor as pf
 import requests
 
 from janitor import check
+from janitor.errors import JanitorError
 
-from .utils import deprecated_alias
+from .utils import deprecated_alias, is_connected
 
 currency_set = {
     "AUD",
@@ -321,6 +321,7 @@ wb_country_dict = {
 
 
 def _check_currency(currency: str):
+    """Check that currency is in supported set."""
     if currency not in currency_set:
         raise ValueError(
             f"currency {currency} not in supported currency set, "
@@ -329,6 +330,7 @@ def _check_currency(currency: str):
 
 
 def _check_wb_country(country: str):
+    """Check that world bank country is in supported set."""
     if (country not in wb_country_dict.keys()) & (
         country not in wb_country_dict.values()  # noqa: PD011
     ):
@@ -339,156 +341,194 @@ def _check_wb_country(country: str):
 
 
 def _check_wb_years(year: int):
+    """Check that year is in world bank dataset years."""
     if year < 1960:
         raise ValueError("year value must be 1960 or later")
 
 
-@lru_cache(maxsize=32)
-def _convert_currency(
-    from_currency: str = None,
-    to_currency: str = None,
-    historical_date: Optional[date] = None,
-) -> float:
-    """
-    Currency conversion for Pandas DataFrame column.
+# @lru_cache(maxsize=32)
+# def _convert_currency(
+#     api_key: str,
+#     from_currency: str = None,
+#     to_currency: str = None,
+#     historical_date: Optional[date] = None,
+# ) -> float:
+#     """
+#     Currency conversion for Pandas DataFrame column.
 
-    Helper function for `convert_currency` method.
+#     Helper function for `convert_currency` method.
 
-    The API used is: https://exchangeratesapi.io/
-    """
+#     The API used is https://exchangeratesapi.io/.
+#     """
 
-    url = "https://api.exchangeratesapi.io"
+#     url = "http://api.exchangeratesapi.io"
 
-    if historical_date:
-        check("historical_date", historical_date, [datetime, date])
-        if isinstance(historical_date, datetime):
-            if historical_date < datetime(1999, 1, 4):
-                raise ValueError(
-                    "historical_date:datetime must be later than 1999-01-04!"
-                )
-            string_date = str(historical_date)[:10]
-        else:
-            if historical_date < date(1999, 1, 4):
-                raise ValueError(
-                    "historical_date:date must be later than 1999-01-04!"
-                )
-            string_date = str(historical_date)
-        url = url + "/%s" % string_date
-    else:
-        url = url + "/latest"
+#     if historical_date:
+#         check("historical_date", historical_date, [datetime, date])
+#         if isinstance(historical_date, datetime):
+#             if historical_date < datetime(1999, 1, 4):
+#                 raise ValueError(
+#                     "historical_date:datetime must be later than 1999-01-04!"
+#                 )
+#             string_date = str(historical_date)[:10]
+#         else:
+#             if historical_date < date(1999, 1, 4):
+#                 raise ValueError(
+#                     "historical_date:date must be later than 1999-01-04!"
+#                 )
+#             string_date = str(historical_date)
+#         url = url + "/%s" % string_date
+#     else:
+#         url = url + "/latest"
 
-    _check_currency(from_currency)
-    _check_currency(to_currency)
+#     _check_currency(from_currency)
+#     _check_currency(to_currency)
 
-    payload = {"base": from_currency, "symbols": to_currency}
+#     payload = {
+#         # "base": from_currency,
+#         "symbols": to_currency,
+#         "access_key": api_key,
+#     }
 
-    result = requests.get(url, params=payload)
+#     result = requests.get(url, params=payload)
 
-    if result.status_code != 200:
-        raise ConnectionError(
-            "Exchange Rate API failed to receive a 200 "
-            "response from the server. "
-            "Please try again later."
-        )
+#     if result.status_code != 200:
+#         raise ConnectionError(
+#             "Exchange Rate API failed to receive a 200 "
+#             "response from the server. "
+#             "Please try again later."
+#         )
 
-    currency_dict = json.loads(result.text)
-    rate = currency_dict["rates"][to_currency]
-    return rate
+#     currency_dict = json.loads(result.text)
+#     rate = currency_dict["rates"][to_currency]
+#     return rate
 
 
 @pf.register_dataframe_method
 @deprecated_alias(colname="column_name")
 def convert_currency(
     df: pd.DataFrame,
+    api_key: str,
     column_name: str = None,
     from_currency: str = None,
     to_currency: str = None,
     historical_date: date = None,
     make_new_column: bool = False,
 ) -> pd.DataFrame:
-    """
-    Converts a column from one currency to another, with an option to
-    convert based on historical exchange values.
+    """Deprecated function."""
+    raise JanitorError(
+        "The `convert_currency` function has been temporarily disabled due to "
+        "exchangeratesapi.io disallowing free pinging of its API. "
+        "(Our tests started to fail due to this issue.) "
+        "There is no easy way around this problem "
+        "except to find a new API to call on."
+        "Please comment on issue #829 "
+        "(https://github.com/pyjanitor-devs/pyjanitor/issues/829) "
+        "if you know of an alternative API that we can call on, "
+        "otherwise the function will be removed in pyjanitor's 1.0 release."
+    )
 
-    This method mutates the original DataFrame.
 
-    :param df: A pandas dataframe.
-    :param column_name: Name of the new column. Should be a string, in order
-        for the column name to be compatible with the Feather binary
-        format (this is a useful thing to have).
-    :param from_currency: The base currency to convert from.
-        May be any of: currency_set = {"AUD", "BGN", "BRL", "CAD", "CHF",
-        "CNY", "CZK", "DKK", "EUR", "GBP", "HKD", "HRK", "HUF", "IDR",
-        "ILS", "INR", "ISK", "JPY", "KRW", "MXN", "MYR", "NOK", "NZD",
-        "PHP", "PLN", "RON", "RUB", "SEK", "SGD", "THB", "TRY", "USD",
-        "ZAR"}
-    :param to_currency: The target currency to convert to.
-        May be any of: currency_set = {"AUD", "BGN", "BRL", "CAD", "CHF",
-        "CNY", "CZK", "DKK", "EUR", "GBP", "HKD", "HRK", "HUF", "IDR",
-        "ILS", "INR", "ISK", "JPY", "KRW", "MXN", "MYR", "NOK", "NZD",
-        "PHP", "PLN", "RON", "RUB", "SEK", "SGD", "THB", "TRY", "USD",
-        "ZAR"}
-    :param historical_date: If supplied, get exchange rate on a certain\
-        date. If not supplied, get the latest exchange rate. The exchange\
-        rates go back to Jan. 4, 1999.
-    :param make_new_column: Generates new column for converted currency if
-        True, otherwise, converts currency in place.
-    :returns: The dataframe with converted currency column.
+# @pf.register_dataframe_method
+# @deprecated_alias(colname="column_name")
+# def convert_currency(
+#     df: pd.DataFrame,
+#     api_key: str,
+#     column_name: str = None,
+#     from_currency: str = None,
+#     to_currency: str = None,
+#     historical_date: date = None,
+#     make_new_column: bool = False,
+# ) -> pd.DataFrame:
+#     """
+#     Converts a column from one currency to another, with an option to
+#     convert based on historical exchange values.
 
-    :Setup:
+#     On April 10 2021,
+#     we discovered that there was no more free API available.
+#     Thus, an API key is required to perform currency conversion.
+#     API keys should be set as an environment variable,
+#     for example, ``EXCHANGE_RATE_API_KEY``,
+#     and then passed into the function
+#     by calling on ``os.getenv("EXCHANGE_RATE_APIKEY")``.
 
-    .. code-block:: python
+#     :param df: A pandas dataframe.
+#     :param api_key: exchangeratesapi.io API key.
+#     :param column_name: Name of the new column. Should be a string, in order
+#         for the column name to be compatible with the Feather binary
+#         format (this is a useful thing to have).
+#     :param from_currency: The base currency to convert from.
+#         May be any of: currency_set = {"AUD", "BGN", "BRL", "CAD", "CHF",
+#         "CNY", "CZK", "DKK", "EUR", "GBP", "HKD", "HRK", "HUF", "IDR",
+#         "ILS", "INR", "ISK", "JPY", "KRW", "MXN", "MYR", "NOK", "NZD",
+#         "PHP", "PLN", "RON", "RUB", "SEK", "SGD", "THB", "TRY", "USD",
+#         "ZAR"}
+#     :param to_currency: The target currency to convert to.
+#         May be any of: currency_set = {"AUD", "BGN", "BRL", "CAD", "CHF",
+#         "CNY", "CZK", "DKK", "EUR", "GBP", "HKD", "HRK", "HUF", "IDR",
+#         "ILS", "INR", "ISK", "JPY", "KRW", "MXN", "MYR", "NOK", "NZD",
+#         "PHP", "PLN", "RON", "RUB", "SEK", "SGD", "THB", "TRY", "USD",
+#         "ZAR"}
+#     :param historical_date: If supplied,
+#         get exchange rate on a certain date.
+#         If not supplied, get the latest exchange rate.
+#         The exchange rates go back to Jan. 4, 1999.
+#     :param make_new_column: Generates new column
+#         for converted currency if True,
+#         otherwise, converts currency in place.
+#     :returns: The dataframe with converted currency column.
 
-        import pandas as pd
-        import janitor
-        from datetime import date
+#     .. code-block:: python
 
-        data_dict = {
-            "a": [1.23452345, 2.456234, 3.2346125] * 3,
-            "Bell__Chart": [1/3, 2/7, 3/2] * 3,
-            "decorated-elephant": [1/234, 2/13, 3/167] * 3,
-            "animals": ["rabbit", "leopard", "lion"] * 3,
-            "cities": ["Cambridge", "Shanghai", "Basel"] * 3,
-        }
+#         import pandas as pd
+#         import janitor
+#         from datetime import date
 
-        example_dataframe = pd.DataFrame(data_dict)
+#         data_dict = {
+#             "a": [1.23452345, 2.456234, 3.2346125] * 3,
+#             "Bell__Chart": [1/3, 2/7, 3/2] * 3,
+#             "decorated-elephant": [1/234, 2/13, 3/167] * 3,
+#             "animals": ["rabbit", "leopard", "lion"] * 3,
+#             "cities": ["Cambridge", "Shanghai", "Basel"] * 3,
+#         }
 
-    :Example: Converting a column from one currency to another using rates
+#         example_dataframe = pd.DataFrame(data_dict)
 
-    from 01/01/2018:
+#     Example: Converting a column from one currency to another
+#     using rates from 01/01/2018.
 
-    .. code-block:: python
+#     .. code-block:: python
 
-        example_dataframe.convert_currency('a', from_currency='USD',
-        to_currency='EUR', historical_date=date(2018,1,1))
+#         example_dataframe.convert_currency('a', from_currency='USD',
+#         to_currency='EUR', historical_date=date(2018,1,1))
 
-    :Output:
+#     Output:
 
-    .. code-block:: python
+#     .. code-block:: python
 
-                    a  Bell__Chart  decorated-elephant  animals     cities
-        0  1.029370     0.333333            0.004274   rabbit  Cambridge
-        1  2.048056     0.285714            0.153846  leopard   Shanghai
-        2  2.697084     1.500000            0.017964     lion      Basel
-        3  1.029370     0.333333            0.004274   rabbit  Cambridge
-        4  2.048056     0.285714            0.153846  leopard   Shanghai
-        5  2.697084     1.500000            0.017964     lion      Basel
-        6  1.029370     0.333333            0.004274   rabbit  Cambridge
-        7  2.048056     0.285714            0.153846  leopard   Shanghai
-        8  2.697084     1.500000            0.017964     lion      Basel
+#                     a  Bell__Chart  decorated-elephant  animals     cities
+#         0  1.029370     0.333333            0.004274   rabbit  Cambridge
+#         1  2.048056     0.285714            0.153846  leopard   Shanghai
+#         2  2.697084     1.500000            0.017964     lion      Basel
+#         3  1.029370     0.333333            0.004274   rabbit  Cambridge
+#         4  2.048056     0.285714            0.153846  leopard   Shanghai
+#         5  2.697084     1.500000            0.017964     lion      Basel
+#         6  1.029370     0.333333            0.004274   rabbit  Cambridge
+#         7  2.048056     0.285714            0.153846  leopard   Shanghai
+#         8  2.697084     1.500000            0.017964     lion      Basel
+#     """
 
-    """
+#     rate = _convert_currency(
+#         api_key, from_currency, to_currency, historical_date
+#     )
 
-    rate = _convert_currency(from_currency, to_currency, historical_date)
+#     if make_new_column:
+#         # new_column_name = column_name + "_" + to_currency
+#         column_name = column_name + "_" + to_currency
 
-    if make_new_column:
-        new_column_name = column_name + "_" + to_currency
-        df[new_column_name] = df[column_name] * rate
+#     df = df.assign(column_name=df[column_name] * rate)
 
-    else:
-        df[column_name] = df[column_name] * rate
-
-    return df
+#     return df
 
 
 @lru_cache(maxsize=32)
@@ -654,3 +694,53 @@ def inflate_currency(
         df[column_name] = df[column_name] * inflator
 
     return df
+
+
+def convert_stock(stock_symbol: str) -> str:
+    """
+    This function takes in a stock symbol as a parameter,
+    queries an API for the companies full name and returns
+    it
+
+    Example:
+        print(convert_stock("aapl"))
+
+        console >> Apple Inc.
+
+    :param stock_symbol: This is our input stock symbol
+        to be converted
+    :raises ConnectionError: if stock ticker data cannot be retrieved
+    :return: We return the full company name
+    """
+    if is_connected("www.google.com"):
+        stock_symbol = stock_symbol.upper()
+        return get_symbol(stock_symbol.upper())
+    else:
+        raise ConnectionError(
+            "Connection Error: Client Not Connected to Internet"
+        )
+
+
+def get_symbol(symbol: str):
+    """
+    This is a helper function to get a companies full
+    name based on the stock symbol.
+
+    Example:
+        print(get_symbol("aapl"))
+        console >> Apple Inc.
+
+    :param symbol: This is our stock symbol that we use
+        to query te api for the companies full name.
+    :return: This is the company name
+    """
+    result = requests.get(
+        "http://d.yimg.com/autoc."
+        + "finance.yahoo.com/autoc?query={}&region=1&lang=en".format(symbol)
+    ).json()
+
+    for x in result["ResultSet"]["Result"]:
+        if x["symbol"] == symbol:
+            return x["name"]
+        else:
+            return None
